@@ -4,7 +4,7 @@ use warnings;
 use 5.006;
 
 package LWP::ConsoleLogger;
-$LWP::ConsoleLogger::VERSION = '0.000020';
+$LWP::ConsoleLogger::VERSION = '0.000021';
 use Data::Printer { end_separator => 1, hash_separator => ' => ' };
 use DateTime qw();
 use HTML::Restrict qw();
@@ -217,7 +217,7 @@ sub _log_params {
                 my $t = Text::SimpleTable::AutoWidth->new;
                 $t->captions( [ $type . ' Parsed Body' ] );
                 $self->_parse_body(
-                    $req->content, $req->header('Content-Type'),
+                    $req->content, scalar $req->header('Content-Type'),
                     $t
                 );
                 $self->_draw($t);
@@ -338,25 +338,38 @@ sub _parse_body {
     my $content_type = shift;
     my $t            = shift;
 
+    # nothing to do here
+    unless ($content_type) {
+        $t->row($content);
+        return;
+    }
+
     my ( $type, $subtype ) = parse_mime_type($content_type);
-    if ( lc $subtype eq 'html' ) {
+    unless ($subtype) {
+        $t->row($content);
+        return;
+    }
+
+    $subtype = lc $subtype;
+
+    if ( $subtype eq 'html' ) {
         $content = $self->html_restrict->process($content);
         $content =~ s{\s+}{ }g;
         $content =~ s{\n{2,}}{\n\n}g;
 
         return if !$content;
     }
-    elsif ( lc $subtype eq 'xml' ) {
+    elsif ( $subtype eq 'xml' ) {
         try {
             my $pretty = XMLin( $content, KeepRoot => 1 );
-            $content = p( $pretty, return_value => 'dump' );
+            $content = np( $pretty, return_value => 'dump' );
         }
         catch { $t->row("Error parsing XML: $_") };
     }
-    elsif ( lc $subtype eq 'json' ) {
+    elsif ( $subtype eq 'json' ) {
         try {
             $content = decode_json($content);
-            $content = p( $content, return_value => 'dump' );
+            $content = np( $content, return_value => 'dump' );
         }
         catch { $t->row("Error parsing JSON: $_") };
     }
@@ -406,7 +419,7 @@ LWP::ConsoleLogger - LWP tracing and debugging
 
 =head1 VERSION
 
-version 0.000020
+version 0.000021
 
 =head1 SYNOPSIS
 
